H <-
function(u) {
u*exp(u)
}

